@@ -52,7 +52,7 @@ ROUTE_ADDER = 'add-bento-route'
 DEFAULT_GLOBAL_SCRIPT_PATH = '/usr/local/bin'
 DEFAULT_BENTO_NAME = 'bento'
 DEFAULT_BENTO_IMAGE = 'kijiproject/bento-cluster'
-DEFAULT_BENTO_PLATFORM = 'cdh5.0.3'
+DEFAULT_BENTO_PLATFORM = 'cdh5.1.3'
 DEFAULT_TIMEOUT_MS = 120000
 DEFAULT_POLL_INTERVAL = 0.1
 
@@ -239,6 +239,8 @@ class BentoSystem(object):
                 bento cluster will run.
             verbose: Set to true to print the response from the docker daemon.
         """
+        logging.info('Pulling the latest Docker images for %s from DockerHub. Please be patient ' \
+            'as this may take a while.' % platform_version)
         response = self.docker_client.pull(
             repository=self.bento_image,
             tag=platform_version,
